pub struct MockMailboxSource {
pub inbox_rows: Vec<MessageRow>,
pub sent_rows: Vec<MessageRow>,
pub channel_rows: Vec<MessageRow>,
pub wire_rows: Vec<MessageRow>,
pub inbox_calls: Mutex<Vec<(String, i64)>>,
pub sent_calls: Mutex<Vec<(String, i64)>>,
pub channel_calls: Mutex<Vec<(String, i64)>>,
pub wire_calls: Mutex<Vec<(String, i64)>>,
}Expand description
Test stub — returns canned rows on each call, records every arg pair. Mailbox is the most-asserted test surface in PR-UI-3 so the recorder lets snapshot + interaction tests verify “is the right filter being asked the right thing.”
Fields
inbox_rows: Vec<MessageRow>sent_rows: Vec<MessageRow>channel_rows: Vec<MessageRow>wire_rows: Vec<MessageRow>inbox_calls: Mutex<Vec<(String, i64)>>sent_calls: Mutex<Vec<(String, i64)>>channel_calls: Mutex<Vec<(String, i64)>>wire_calls: Mutex<Vec<(String, i64)>>Trait Implementations
Sourceimpl Default for MockMailboxSource
impl Default for MockMailboxSource
Sourcefn default() -> MockMailboxSource
fn default() -> MockMailboxSource
Returns the “default value” for a type. Read more
Sourceimpl MailboxSource for MockMailboxSource
impl MailboxSource for MockMailboxSource
fn inbox(&self, agent_id: &str, after_id: i64) -> Result<Vec<MessageRow>>
fn sent(&self, agent_id: &str, after_id: i64) -> Result<Vec<MessageRow>>
fn channel_feed(&self, agent_id: &str, after_id: i64) -> Result<Vec<MessageRow>>
fn wire(&self, project_id: &str, after_id: i64) -> Result<Vec<MessageRow>>